<%inherit file="master.html"/> <%def name="counts_box(r, status)">
${release_updates_counts[r['name']][status+'_updates_total']}
<%def name="release_list(release_status, stable_only=False)"> <% if release_status == 'pending': releases_list = request.releases['pending'] + request.releases['frozen'] else: releases_list = request.releases[release_status] %>\

- ${release_status.capitalize()} Releases ${len(releases_list)}
  % if not stable_only:
  Pending
  Testing
  % endif
  Stable
% for r in sorted(releases_list, key=lambda i: i['name'], reverse=True):
- ${r['long_name']} % if r['state'] == 'frozen': ${self.fragments.frozen_badge()} % endif
  % if not stable_only: ${counts_box(r, "pending")} ${counts_box(r, "testing")} % endif ${counts_box(r, "stable")}
% endfor

% if active:

### Active Releases

See here for Archived and disabled Releases % else:

### Archived and disabled Releases

See here for Active Releases % endif
% if active: ${release_list('current', stable_only=False)} ${release_list('pending', stable_only=False)} % else: ${release_list('archived', stable_only=True)} % if request.releases['disabled']: ${release_list('disabled', stable_only=True)} % endif % endif
<%block name="javascript"> ${parent.javascript()}